class Admin::BooksController < OrbitMemberController
  include Admin::JournalPapersHelper

  before_action :set_book, only: [:show, :edit , :update, :destroy]
  before_action :get_plugins, only: [:index, :book_setting, :new, :create, :edit, :update]
  before_action :set_types, only: [:index,:book_setting, :new, :edit, :create, :update]

  def index
  	@writing_books = Book.all
    respond_to do |format|
      format.html # index.html.erb
      format.js { }
      format.xml  { render :xml => @books }
    end
  end

  def show
  	respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @book }
    end
  end

  def edit
    @members_data = Book.member_data rescue nil
  end

  def update
   @book_authors = @book.book_authors
    
    respond_to do |format|
      if @book.update_attributes(book_attributes)
        format.html { redirect_to admin_books_path }
        format.xml  { head :ok }
      else
        format.html { render action: "edit" }
        format.xml  { render :xml => @book.errors, :status => :unprocessable_entity }
      end
    end
  end

  def new
    @book = Book.new
    @members_data = Book.member_data rescue nil

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @book }
    end
  end

  def create
  	@book = Book.new(book_attributes)
    respond_to do |format|
      if @book.save
        format.html { redirect_to admin_books_path }
        format.xml  { render :xml => @book, :status => :created, :location => @book }
      else
        format.html { render action: "new" }
        format.xml  { render :xml => @book.errors, :status => :unprocessable_entity }
      end
     end
  end

  def book_setting  
    @set_author_type = BookAuthorType.new(display: 'List')
    @author_type_url = admin_books_path
  
    @set_book_type = BookType.new(display: 'List')
    @book_type_url = admin_books_path
  end

  def destroy
  	@book.destroy

    respond_to do |format|     
      format.html { redirect_to(admin_books_url) }
      format.js
    end
  end

  def add_author_type
  	@set_author_type = BookAuthorType.new(display: 'List')
    @author_type_url = admin_book_author_types_path
    @set_author_type.id = params[:id]
	
    respond_to do |format|
      format.js
    end
  end

  def edit_author_type
    @set_author_type = BookAuthorType.find(params[:book_id])
    @author_type_url = admin_book_author_type_path(@set_author_type)
	
    respond_to do |format|
      format.js
    end
  end

  def add_book_type
  	@set_book_type = BookType.new(display: 'List')
  	@book_type_url = admin_book_types_path
  	@set_book_type.id = params[:id]

    respond_to do |format|
      format.js
    end
  end

  def edit_book_type
  	@set_book_type = BookType.find(params[:book_id])
  	@book_type_url = admin_book_type_path(@set_book_type)

  	respond_to do |format|
      format.js
    end
  end

  def data_share
    if params[:ids]
      @books = Book.any_in(_id: params[:ids])

      @books.each do |book|
        book.is_hidden = params[:disable]
        book.save
      end
    end

    respond_to do |format|
       format.html { redirect_to(admin_member_path(id: params[:member_profile_id],show_plugin_profile: "Book")) }
       format.json { render json: {"success"=>true}.to_json}
    end
  end

  def delete
  end

  private

  def set_book
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
  	@book = Book.find_by(uid: uid)
  end

  def book_attributes
  	params.require(:book).permit! rescue nil
  end

  def get_plugins
  	@plugins = OrbitApp::Plugin::Registration.all rescue nil
  end

  def set_types
    @author_types = BookAuthorType.all
    @book_types = BookType.all
  end 
end
